@@ -64,7 +64,8 @@ sub meta_merge {
 	dynamic_config	=> 1,
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://github.com/trwyant/perl-Test-Prereq-Meta/issues',
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Prereq-Meta',
+		# web	=> 'https://github.com/trwyant/perl-Test-Prereq-Meta/issues',
 		mailto  => 'wyant@cpan.org',
 	    },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -130,7 +131,6 @@ sub requires_perl {
     return 5.010;
 }
 
-
 sub script_files {
     return [
     ];
@@ -290,7 +290,6 @@ distribution's version is to be derived.
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -299,10 +298,10 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Prereq-Meta>,
 L<https://github.com/trwyant/perl-Test-Prereq-Meta/issues>, or in
 electronic mail to the author.
 
